%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Cluster Statistics
% XX November 2006, Release 0.9
%
% Input:
%
% Output:
%
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ')
disp('--> Running Cluster Statistics')

% load needed MAT files
load ChanNum
cd(strcat('CM',num2str(ChanNum)))
load ClusterInfo; load RayInfo; load FullVectors
cd ..

% determine the number of clusters and the number of channel realizations
[NumClusters,NumChannels]=size(ToaCluster);

% get channel model params based on this channel model number
[n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
nlos, TSV, SynNLOS] = params( ChanNum );

% now calculate the cluster statistics
if NumClusters>1 % meaning we have multi-clusters
    
    % Cluster Lambda - Arrival Rate
    LambdaCluster=1/mean(mean(ToaCluster(2:end,:)-ToaCluster(1:end-1,:)));

    % Ray Lambda - Arrival Rate
    LambdaRay=1/mean(mean(mean(ToaRay(2:end,2:end,:)-...
        ToaRay(1:end-1,2:end,:)))); % don't use first cluster since it is contrived

    % Cluster Gamma - Decay Factor
    temp1=10^((Delta_CapK)/10);
    GammaCluster=mean(mean(-ToaCluster(2:end,:)./log(temp1*...
        AvePowCluster(2:end,:)))); % don't use first cluster since it is contrived

    % Ray Gamma - Decay Factor
    temp2=10^((Delta_LowK)/10);
    temp3=zeros(NumClusters-1,NumChannels); % don't use first cluster since it is contrived
    for ChanIndex=1:NumChannels
        for ClusterIndex=2:NumClusters
            temp3(ClusterIndex,ChanIndex)=mean(-ToaRay(:, ClusterIndex,...
                ChanIndex)./log(AvePowRay(:,ClusterIndex,ChanIndex)/...
                (temp2*InsPowCluster(ClusterIndex,ChanIndex)))); % don't use first cluster since it is contrived
        end
    end
    GammaRay=mean(mean(temp3)); % determine the mean GammaRay

    % Cluster Sigma - Cluster Amplitude Standard Deviation
    ClusterSigma=mean(mean(abs(10*log10(InsPowCluster(2:end,:)./...
        AvePowCluster(2:end,:))))); % don't use first cluster since it is contrived

    % Ray Sigma - Ray Amplitude Standard Deviation
    RaySigma=mean(mean(mean(abs(10*log10(InsPowRay(:,2:end,:)./...
        AvePowRay(:,2:end,:)))))); % don't use first cluster since it is contrived

    % Ray AoA Sigma - Ray Angle of Arrival Standard Deviation
    AoaSigma=180*sqrt(mean(mean(mean(AoaRay(:,2:end,:).^2))))/pi; % don't use first cluster since it is contrived

    disp(' ')
    disp(strcat('Cluster Statistics for Channel Model #',num2str(ChanNum),' ...'));
    disp(strcat('  Cluster Lambda (1/ns): Desired =',num2str(CapLambda), '  Measured =',num2str(LambdaCluster)))
    disp(strcat('  Ray Lambda (1/ns): Desired =',num2str(LowLambda), '  Measured =',num2str(LambdaRay)))
    disp(strcat('  Cluster Gamma (ns): Desired =',num2str(CapGamma), '  Measured =',num2str(GammaCluster)))
    disp(strcat('  Ray Gamma (ns): Desired =',num2str(LowGamma), '  Measured =',num2str(GammaRay)))
    disp(strcat('  Cluster SD (dB): Desired =',num2str(LowSigma_c), '  Measured =',num2str(ClusterSigma)))
    disp(strcat('  Ray SD (dB): Desired =',num2str(LowSigma_r), '  Measured =',num2str(RaySigma)))
    disp(strcat('  Ray AoA SD (degs): Desired =',num2str(LowSigma_phi), '  Measured =',num2str(AoaSigma)))
    disp(' ')
    
else % single clusters
    
    % Ray Lambda - Arrival Rate
    LambdaRay=1/mean(mean(mean(ToaRay(2:end,1,:)-ToaRay(1:end-1,1,:)))); % don't use first cluster since it is contrived

    % Ray Gamma - Decay Factor
    temp2=10^((Delta_LowK)/10);
    temp3=zeros(1,NumChannels); % don't use first cluster since it is contrived
    for ChanIndex=1:NumChannels
        temp3(1,ChanIndex)=mean(-ToaRay(:, 1, ChanIndex)./log(AvePowRay(:,1,ChanIndex)/...
            (temp2*InsPowCluster(1,ChanIndex)))); % don't use first cluster since it is contrived
    end
    GammaRay=mean(mean(temp3));

    % Ray Sigma - Ray Amplitude Standard Deviation
    RaySigma=mean(mean(mean(abs(10*log10(InsPowRay(:,1,:)./...
    AvePowRay(:,1,:)))))); % don't use first cluster since it is contrived

    % Ray AoA Sigma - Ray Angle of Arrival Standard Deviation
    AoaSigma=180*sqrt(mean(mean(mean(AoaRay(:,1,:).^2))))/pi; % don't use first cluster since it is contrived

    disp(' ')
    disp(strcat('Cluster Statistics for Channel Model #',num2str(ChanNum),' ...'));
    disp(strcat('  Cluster Lambda (1/ns): Desired =',' ---', '  Measured =',' ---'))
    disp(strcat('  Ray Lambda (1/ns): Desired =',num2str(LowLambda), '  Measured =',num2str(LambdaRay)))
    disp(strcat('  Cluster Gamma (ns): Desired =',' ---', '  Measured =',' ---'))
    disp(strcat('  Ray Gamma (ns): Desired =',num2str(LowGamma), '  Measured =',num2str(GammaRay)))
    disp(strcat('  Cluster SD (dB): Desired =',' ---', '  Measured =',' ---'))
    disp(strcat('  Ray SD (dB): Desired =',num2str(LowSigma_r), '  Measured =',num2str(RaySigma)))
    disp(strcat('  Ray AoA SD (degs): Desired =',num2str(LowSigma_phi), '  Measured =',num2str(AoaSigma)))
    disp(' ')
    
end

% find the strongest ray in each realization and the related AoA
[MaxVal, MaxInd]=max(InsPowVector);

% plot some statistics
figure(1)
stem(MaxVal)
title('Max Ray Pow by Channel Number')
xlabel('channel number'); ylabel('power')

BigAng=zeros(ChanNum,1); % preallocate for speed
for ChanNum=1:NumChannels
    BigAng(ChanNum)=180*AoaWrappedVector(MaxInd(ChanNum),ChanNum)/pi;
end

figure(2)
stem(BigAng)
title('AoA for Max Ray Pow by Channel Number')
xlabel('channel number'); ylabel('degrees')
