%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Continuous Time to Discrete Time
% XX November 2006, Release 0.9
%
% This routine converts cntinuous time to discrete time
%
% Input:
%   1. h_ct = array of continuous time impulse response values ... NxM
%   2. t = array of continuous time values ... NxM
%   3. num_channels = number of realizations for this CM
%   4. ts = sample time step
% 
% Output:
%   1. h_ct = array of continuous time impulse response values ... LxM
% 
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [h_dt] = ct2dt( h_ct, t, num_channels, ts )

% search for largest continuous time and convert to largest discrete time
MaxTimeIndex=ceil(max(max(t))*1e-9/ts); % convert continuous ns to discrete time index
MaxTime=MaxTimeIndex*ts; % convert discrete time index to nanoseconds

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Conversion Algorithm:
% 1. assign a time bin based upon the continuous time value
% 2. use this time bin to assign an amplitude value to the discrete array
%    from the continuous time array
% 3. add to the discrete time assignment any previously assigned discrete
%    time values (time bin quantization effect)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_dt=zeros(MaxTimeIndex,num_channels); % impulse response in discrete time
for ChanIndex=1:num_channels % count realizations
    for RayIndex=1:length(t(:,1)) % count rays within a realization
        TimeBin=floor(MaxTimeIndex*(t(RayIndex,ChanIndex)*1e-9)/MaxTime); % find time bin, array "t" is in nS
        h_dt(TimeBin+1,ChanIndex)=h_dt(TimeBin+1,ChanIndex)+...
            h_ct(RayIndex,ChanIndex); % assign value
    end
end
