%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Fetch S-V Parameters
% XX November 2006, Release 0.9
%
% Input:
%
% Output:
%
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
    LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
    nlos, TSV, SynNLOS] = params( cm_num )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%
% Return modified S-V model parameters for TG3c channel models
% n                 Path Loss Exponent
% PLo               Free Space Path Loss at Reference Distance 
% LowSigma_s        Standard Deviation of Path Loss Shadowing
% CapLambda         Cluster arrival rate (clusters per nsec)
% LowLambda         Ray arrival rate (rays per nsec)
% CapGamma          Cluster Decay Factor
% LowGamma          Ray Decay Factor
% LowSigma_c        Standard Deviation of Cluster Lognormal Fading Term (dB)
% LowSigma_r        Standard Deviation of Ray Lognormal Fading Term (dB)
% LowSignma_phi     Standard Deviation of the Ray Angle of Arrival
% L_mean            Mean number of Clusters
% Delta_CapK        LOS Rician Factor
% Delta_LowK        Cluster First Ray Factor
% nlos              Flag for non line of sight channel
%                       0 -> LOS
%                       1 -> NLOS
% TSV_flag          Flag for non line of sight channel
%                       0 -> Regualr LOS
%                       1 -> TSV LOS
% SynNLOS           Flag for non line of sight channel
%                       0 -> Regular NLOS
%                       1 -> Synthesize NLOS from LOS model
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% ParamStore definition:
%
% ParamStore(cm_num, ... 17 S-V parameters ...)
%
% dimensions: ParamStore (17, 17)
%
%  ParamStore(10*cm_num, 1)= NaN; % n
%  ParamStore(10*cm_num, 2)= NaN; % PLo
%  ParamStore(10*cm_num, 3)= NaN; % LowSigma_s
%  ParamStore(10*cm_num, 4)= 1.72; % CapLambda
%  ParamStore(10*cm_num, 5)= 3.14; % LowLambda
%  ParamStore(10*cm_num, 6)= 4.01; % CapGamma
%  ParamStore(10*cm_num, 7)= 0.58; % LowGamma
%  ParamStore(10*cm_num, 8)= 2.7; % LowSigma_c
%  ParamStore(10*cm_num, 9)= 1.9; % LowSigma_r
%  ParamStore(10*cm_num, 10)= 14; % LowSigma_phi
%  ParamStore(10*cm_num, 11)= 14; % L_mean
%  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
%  ParamStore(10*cm_num, 13)= NaN; % Delta_LowK
%  ParamStore(10*cm_num, 14)= NaN; % CapOmega
%  ParamStore(10*cm_num, 15)= 8.0; % fs
%  ParamStore(10*cm_num, 16)= 0; %nlos
%  ParamStore(10*cm_num, 17)= 0; % TSV flag
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load SvStore; % load all the S-V parameters for all channel models

if mod(cm_num,1)~=0
    cm_num=10*cm_num;
end

n = ParamStore(cm_num, 1); % n
PLo = ParamStore(cm_num, 2); % PLo
LowSigma_s = ParamStore(cm_num, 3); % LowSigma_s
CapLambda = ParamStore(cm_num, 4); % CapLambda
LowLambda = ParamStore(cm_num, 5); % LowLambda
CapGamma = ParamStore(cm_num, 6); % CapGamma
LowGamma = ParamStore(cm_num, 7); % LowGamma
LowSigma_c = ParamStore(cm_num, 8); % LowSigma_c
LowSigma_r = ParamStore(cm_num, 9); % LowSigma_r
LowSigma_phi = ParamStore(cm_num, 10); % LowSigma_phi
L_mean = ParamStore(cm_num, 11); % L_mean
Delta_CapK = ParamStore(cm_num, 12); % Delta_CapK
Delta_LowK = ParamStore(cm_num, 13); % Delta_LowK
nlos = ParamStore(cm_num, 14); % nlos
TSV = ParamStore(cm_num, 15); % TSV Flay
SynNLOS = ParamStore(cm_num, 16); %SynNLOS

return
  